@@ -5,10 +5,10 @@
 #' @param x ppp
 #' @param nsim Number of patterns to simulate.
 #' @param fix_n Logical if true the null model patterns have exactly the same number of points ais input.
-#' @param ... Arguments passed to \code{spatstat.core::density.ppp()}.
+#' @param ... Arguments passed to \code{spatstat.explore::density.ppp()}.
 #'
 #' @details
-#' Simulate heterogeneous point patterns as null model data for \code{spatstat.core::envelope()}.
+#' Simulate heterogeneous point patterns as null model data for \code{spatstat.explore::envelope()}.
 #' A heterogeneous Poisson process is used, meaning that there are no interaction between points,
 #' however, the simulated coordinates depend on the intensity \eqn{\lambda} of the input pattern.
 #'
@@ -24,7 +24,7 @@
 #' set.seed(42)
 #' input_pattern <- spatstat.random::rpoispp(lambda = function(x , y) {100 * exp(-3 * x)}, nsim = 1)
 #' null_model <- simulate_heterogenous_pattern(input_pattern, nsim = 19)
-#' spatstat.core::envelope(Y = input_pattern, fun = spatstat.core::pcf, nsim = 19,
+#' spatstat.explore::envelope(Y = input_pattern, fun = spatstat.explore::pcf, nsim = 19,
 #' simulate = null_model)
 #'
 #' @references
@@ -40,11 +40,11 @@
 #' @export
 simulate_heterogenous_pattern <- function(x, nsim, fix_n = FALSE, ...) {
 
-  if (class(x) != "ppp") {
+  if (!inherits(x = x, what = "ppp")) {
     stop("Please provide ppp object.", call. = FALSE)
   }
 
-  lambda_xy <- spatstat.core::density.ppp(x, ...)
+  lambda_xy <- spatstat.explore::density.ppp(x, ...)
 
   # check if exactly same number of points
   if (fix_n) {
