@@ -2,7 +2,7 @@ context("test-balance_points")
 
 test_that("balance_points works for integer n", {
 
-  input <- spatstat.core::rpoispp(lambda = 100)
+  input <- spatstat.random::rpoispp(lambda = 100)
 
   result <- balance_points(pattern = input, n = 110)
 
@@ -11,8 +11,8 @@ test_that("balance_points works for integer n", {
 
 test_that("balance_points works for ppp n", {
 
-  input <- spatstat.core::rpoispp(lambda = 100)
-  input_b <- spatstat.core::rpoispp(lambda = 100)
+  input <- spatstat.random::rpoispp(lambda = 100)
+  input_b <- spatstat.random::rpoispp(lambda = 100)
 
   result <- balance_points(pattern = input, n = input_b)
 
@@ -21,7 +21,7 @@ test_that("balance_points works for ppp n", {
 
 test_that("balance_points returns error", {
 
-  input <- spatstat.core::rpoispp(lambda = 100)
+  input <- spatstat.random::rpoispp(lambda = 100)
 
   expect_error(object = balance_points(pattern = input, n = 50.5),
                regexp = "n must be either integer or ppp.")
@@ -29,7 +29,7 @@ test_that("balance_points returns error", {
 
 test_that("balance_points returns warning", {
 
-  input <- spatstat.core::rpoispp(lambda = 100)
+  input <- spatstat.random::rpoispp(lambda = 100)
 
   expect_warning(object = balance_points(pattern = input, n = 20),
                  regexp = "Differences between pattern and n more than 0.33.")
